==> ejc-jlprogress-impl-3.0.0-20241016.094058-340-sources.jar: com/ejianc/business/jlprogress/progress/bean/TotalPlanDetailChangeEntity.java <==
package com.ejianc.business.jlprogress.progress.bean;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.business.jlprogress.progress.utils.DateUtil;
import com.ejianc.business.jlprogress.progress.vo.TotalPlanDetailChangeVO;
import org.apache.commons.lang3.StringUtils;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 总计划详情变更
 *
 * @author generator
 */
@TableName("ejc_zjkjprogress_total_plan_detail_change")
public class TotalPlanDetailChangeEntity extends ProgressDetailEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "total_id")
    private Long totalId; // 总计划主键
    @TableField(value = "total_bid")
    private Long totalBid; // 主表主键

    @TableField(value = "task_line")
    private Integer taskLine; // 任务条线(手续线、设计线、建造线、招采线)
    @TableField(value = "node_level")
    private Integer nodeLevel; // 节点级别
    @TableField(value = "employee_id")
    private String employeeId; // 负责人主键
    @TableField(value = "employee_name")
    private String employeeName; // 负责人名称
    @TableField(value = "plan_num")
    private BigDecimal planNum; // 工程量
    @TableField(value = "unit")
    private Integer unit; // 单位(枚举格式， 包含：㎡、m、m3、kg、t、个)
    @TableField(value = "resource_name")
    private String resourceName; // 资源名称
    @TableField(value = "type")
    private Integer type; // 资源类型(劳动力、材料、机械)
    @TableField(value = "type_unit")
    private Integer typeUnit; // 资源单位(㎡、m、m3、kg、t、个、台班、工日)
    @TableField(value = "need_num")
    private BigDecimal needNum; // 需求量
    @TableField(value="change_type")
    private Integer changeType; // 变更类型,0-未变更,1-变更项,2-新增项,3-删除项,11-变更开始,12-变更完成,112-变更开始完成

    @TableField(exist=false)
    private List<TotalPlanDetailChangeEntity> children = new ArrayList<>();// 子任务

    @TableField(value="last_start")
    private Date lastStart; // 上次生效开始时间
    @TableField(value="last_finish")
    private Date lastFinish; // 上次生效完成时间


    public Date getLastStart() {
        return lastStart;
    }

    public void setLastStart(Date lastStart) {
        this.lastStart = lastStart;
    }

    public Date getLastFinish() {
        return lastFinish;
    }

    public void setLastFinish(Date lastFinish) {
        this.lastFinish = lastFinish;
    }

    public Integer getChangeType() {
        return changeType;
    }

    public void setChangeType(Integer changeType) {
        this.changeType = changeType;
    }

    public Long getTotalId() {
        return totalId;
    }

    public void setTotalId(Long totalId) {
        this.totalId = totalId;
    }

    public Long getTotalBid() {
        return totalBid;
    }

    public void setTotalBid(Long totalBid) {
        this.totalBid = totalBid;
    }

    public Integer getTaskLine() {
        return taskLine;
    }

    public void setTaskLine(Integer taskLine) {
        this.taskLine = taskLine;
    }

    public Integer getNodeLevel() {
        return nodeLevel;
    }

    public void setNodeLevel(Integer nodeLevel) {
        this.nodeLevel = nodeLevel;
    }

    public String getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(String employeeId) {
        this.employeeId = employeeId;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public BigDecimal getPlanNum() {
        return planNum;
    }

    public void setPlanNum(BigDecimal planNum) {
        this.planNum = planNum;
    }

    public Integer getUnit() {
        return unit;
    }

    public void setUnit(Integer unit) {
        this.unit = unit;
    }

    public String getResourceName() {
        return resourceName;
    }

    public void setResourceName(String resourceName) {
        this.resourceName = resourceName;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public Integer getTypeUnit() {
        return typeUnit;
    }

    public void setTypeUnit(Integer typeUnit) {
        this.typeUnit = typeUnit;
    }

    public BigDecimal getNeedNum() {
        return needNum;
    }

    public void setNeedNum(BigDecimal needNum) {
        this.needNum = needNum;
    }

    public List<TotalPlanDetailChangeEntity> getChildren() {
        return children;
    }

    public void setChildren(List<TotalPlanDetailChangeEntity> children) {
        this.children = children;
    }

    /**
     * entity to vo
     */
    public static TotalPlanDetailChangeVO convertEntityToVo(TotalPlanDetailChangeEntity entity) {
        TotalPlanDetailChangeVO progressDetailVo = new TotalPlanDetailChangeVO();
        progressDetailVo.setUid(entity.getId().toString());
        progressDetailVo.setManual(entity.getManual());
        progressDetailVo.setActualDuration(entity.getActualDuration());
        progressDetailVo.setDuration(entity.getDuration());
        progressDetailVo.setPercentComplete(entity.getPercentComplete());
        progressDetailVo.setDepartment(entity.getDepartment());
        progressDetailVo.setProjectUID(entity.getProjectId());
        progressDetailVo.setMilestone(entity.getMilestone());
        progressDetailVo.setFinish(entity.getFinish());
        progressDetailVo.setConstraintType(entity.getConstraintType());
        progressDetailVo.setPrincipal(entity.getPrincipal());
        progressDetailVo.setParentTaskUID(entity.getParentId() + "");
        progressDetailVo.setWbs(entity.getWbs());
        if (StringUtils.isNotBlank(entity.getAssignments())) {
            progressDetailVo.setAssignments(JSON.parseArray(entity.getAssignments()));
        }
        progressDetailVo.setStart(entity.getStart());
        progressDetailVo.setOutlineLevel(entity.getOutlineLevel());
        progressDetailVo.setOutlineNumber(entity.getOutlineNumber());
        progressDetailVo.setCritical(entity.getCritical());
        progressDetailVo.setNote(entity.getNotes());
        progressDetailVo.setSummary(entity.getSummary());
        progressDetailVo.setActualFinish(entity.getActualFinish());
        progressDetailVo.setName(entity.getName());
        progressDetailVo.setId(entity.getTid());
        progressDetailVo.setCode(entity.getCode());
        progressDetailVo.setStructCode(entity.getStructCode());
        progressDetailVo.setWeight(entity.getWeight());
        progressDetailVo.setFixedDate(entity.getFixedDate());
        progressDetailVo.setWork(entity.getWork());
        progressDetailVo.setConstraintDate(entity.getConstraintDate());
        if(StringUtils.isNotBlank(entity.getPredecessorLink())) {
            progressDetailVo.setPredecessorLink(JSON.parseArray(entity.getPredecessorLink()));
        }
        progressDetailVo.setPriority(entity.getPriority());
        progressDetailVo.setActualStart(entity.getActualStart());

        progressDetailVo.setTotalId(entity.getTotalId()); // 总计划主键
        progressDetailVo.setTotalBid(entity.getTotalBid()); // 主表主键

        progressDetailVo.setTaskLine(entity.getTaskLine()); // 任务条线(手续线、设计线、建造线、招采线)
        progressDetailVo.setNodeLevel(entity.getNodeLevel()); // 节点级别
        progressDetailVo.setEmployeeId(entity.getEmployeeId()); // 负责人主键
        progressDetailVo.setEmployeeName(entity.getEmployeeName()); // 负责人名称
        progressDetailVo.setPlanNum(entity.getPlanNum()); // 工程量
        progressDetailVo.setUnit(entity.getUnit()); // 单位(枚举格式， 包含：㎡、m、m3、kg、t、个)
        progressDetailVo.setResourceName(entity.getResourceName()); // 资源名称
        progressDetailVo.setType(entity.getType()); // 资源类型(劳动力、材料、机械)
        progressDetailVo.setTypeUnit(entity.getTypeUnit()); // 资源单位(㎡、m、m3、kg、t、个、台班、工日)
        progressDetailVo.setNeedNum(entity.getNeedNum()); // 需求量
        progressDetailVo.setChangeType(entity.getChangeType());
        progressDetailVo.setLastStart(entity.getLastStart());
        progressDetailVo.setLastFinish(entity.getLastFinish());
        progressDetailVo.setWbsParent(entity.getWbsParent());
        progressDetailVo.setUnitName(entity.getUnitName());
        return progressDetailVo;
    }

    /**
     * vo to entity
     */
    public static TotalPlanDetailChangeEntity convertVoToEntity(TotalPlanDetailChangeVO vo) {
        TotalPlanDetailChangeEntity progressDetailEntity = new TotalPlanDetailChangeEntity();
        if(StringUtils.isNotBlank(vo.getUid())) {
            progressDetailEntity.setId(Long.parseLong(vo.getUid()));
        }
        progressDetailEntity.setManual(vo.getManual());
        progressDetailEntity.setActualDuration(vo.getActualDuration());
        progressDetailEntity.setDuration(vo.getDuration());
        progressDetailEntity.setPercentComplete(vo.getPercentComplete());
        progressDetailEntity.setDepartment(vo.getDepartment());
        progressDetailEntity.setProjectId(vo.getProjectUID());
        progressDetailEntity.setMilestone(vo.getMilestone());
        progressDetailEntity.setFinish(vo.getFinish());
        progressDetailEntity.setConstraintType(vo.getConstraintType());
        progressDetailEntity.setPrincipal(vo.getPrincipal());
        if(StringUtils.isNotBlank(vo.getParentTaskUID())) {
            progressDetailEntity.setParentId(Long.parseLong(vo.getParentTaskUID()));
        }
        progressDetailEntity.setWbs(vo.getWbs());
        if(vo.getAssignments() != null && vo.getAssignments().size() > 0) {
            progressDetailEntity.setAssignments(JSON.toJSONString(vo.getAssignments()));
        }
        progressDetailEntity.setStart(vo.getStart());
        progressDetailEntity.setOutlineLevel(vo.getOutlineLevel());
        progressDetailEntity.setOutlineNumber(vo.getOutlineNumber());
        progressDetailEntity.setCritical(vo.getCritical());
        progressDetailEntity.setNotes(vo.getNote());
        progressDetailEntity.setSummary(vo.getSummary());
        progressDetailEntity.setActualFinish(vo.getActualFinish());
        progressDetailEntity.setName(vo.getName());
        progressDetailEntity.setTid(vo.getId());
        progressDetailEntity.setCode(vo.getCode());
        progressDetailEntity.setStructCode(vo.getStructCode());
        progressDetailEntity.setWeight(vo.getWeight());
        progressDetailEntity.setFixedDate(vo.getFixedDate());
        progressDetailEntity.setWork(vo.getWork());
        progressDetailEntity.setConstraintDate(vo.getConstraintDate());
        if(vo.getPredecessorLink() != null && vo.getPredecessorLink().size() > 0) {
            progressDetailEntity.setPredecessorLink(JSON.toJSONString(vo.getPredecessorLink()));
        }
        progressDetailEntity.setPriority(vo.getPriority());
        progressDetailEntity.setActualStart(vo.getActualStart());

        progressDetailEntity.setTotalId(vo.getTotalId()); // 总计划主键
        progressDetailEntity.setTotalBid(vo.getTotalBid()); // 主表主键

        progressDetailEntity.setTaskLine(vo.getTaskLine()); // 任务条线(手续线、设计线、建造线、招采线)
        progressDetailEntity.setNodeLevel(vo.getNodeLevel()); // 节点级别
        progressDetailEntity.setEmployeeId(vo.getEmployeeId()); // 负责人主键
        progressDetailEntity.setEmployeeName(vo.getEmployeeName()); // 负责人名称
        progressDetailEntity.setPlanNum(vo.getPlanNum()); // 工程量
        progressDetailEntity.setUnit(vo.getUnit()); // 单位(枚举格式， 包含：㎡、m、m3、kg、t、个)
        progressDetailEntity.setResourceName(vo.getResourceName()); // 资源名称
        progressDetailEntity.setType(vo.getType()); // 资源类型(劳动力、材料、机械)
        progressDetailEntity.setTypeUnit(vo.getTypeUnit()); // 资源单位(㎡、m、m3、kg、t、个、台班、工日)
        progressDetailEntity.setNeedNum(vo.getNeedNum()); // 需求量
        progressDetailEntity.setChangeType(vo.getChangeType());
        progressDetailEntity.setLastStart(DateUtil.setHours(vo.getLastStart(), 8));
        progressDetailEntity.setLastFinish(DateUtil.setHours(vo.getLastFinish(), 17));
        progressDetailEntity.setWbsParent(vo.getWbsParent());
        progressDetailEntity.setUnitName(vo.getUnitName());
        return progressDetailEntity;
    }
}

==> ejc-jlprogress-impl-3.0.0-20241111.102036-407-sources.jar: com/ejianc/business/jlprogress/progress/bean/TotalPlanDetailChangeEntity.java <==
package com.ejianc.business.jlprogress.progress.bean;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.business.jlprogress.progress.utils.DateUtil;
import com.ejianc.business.jlprogress.progress.vo.TotalPlanDetailChangeVO;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import org.apache.commons.lang3.StringUtils;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 总计划详情变更
 *
 * @author generator
 */
@TableName("ejc_zjkjprogress_total_plan_detail_change")
public class TotalPlanDetailChangeEntity extends ProgressDetailEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "total_id")
    private Long totalId; // 总计划主键
    @TableField(value = "total_bid")
    private Long totalBid; // 主表主键

    @TableField(value = "task_line")
    private Integer taskLine; // 任务条线(手续线、设计线、建造线、招采线)
    @TableField(value = "node_level")
    private Integer nodeLevel; // 节点级别
    @TableField(value = "employee_id")
    private String employeeId; // 负责人主键
    @TableField(value = "employee_name")
    private String employeeName; // 负责人名称
    @TableField(value = "plan_num")
    private BigDecimal planNum; // 工程量
    @TableField(value = "unit")
    private Integer unit; // 单位(枚举格式， 包含：㎡、m、m3、kg、t、个)
    @TableField(value = "resource_name")
    private String resourceName; // 资源名称
    @TableField(value = "type")
    private Integer type; // 资源类型(劳动力、材料、机械)
    @TableField(value = "type_unit")
    private Integer typeUnit; // 资源单位(㎡、m、m3、kg、t、个、台班、工日)
    @TableField(value = "need_num")
    private BigDecimal needNum; // 需求量
    @TableField(value="change_type")
    private Integer changeType; // 变更类型,0-未变更,1-变更项,2-新增项,3-删除项,11-变更开始,12-变更完成,112-变更开始完成

    @TableField(exist=false)
    private List<TotalPlanDetailChangeEntity> children = new ArrayList<>();// 子任务

    @TableField(value="last_start")
    private Date lastStart; // 上次生效开始时间
    @TableField(value="last_finish")
    private Date lastFinish; // 上次生效完成时间


    public Date getLastStart() {
        return lastStart;
    }

    public void setLastStart(Date lastStart) {
        this.lastStart = lastStart;
    }

    public Date getLastFinish() {
        return lastFinish;
    }

    public void setLastFinish(Date lastFinish) {
        this.lastFinish = lastFinish;
    }

    public Integer getChangeType() {
        return changeType;
    }

    public void setChangeType(Integer changeType) {
        this.changeType = changeType;
    }

    public Long getTotalId() {
        return totalId;
    }

    public void setTotalId(Long totalId) {
        this.totalId = totalId;
    }

    public Long getTotalBid() {
        return totalBid;
    }

    public void setTotalBid(Long totalBid) {
        this.totalBid = totalBid;
    }

    public Integer getTaskLine() {
        return taskLine;
    }

    public void setTaskLine(Integer taskLine) {
        this.taskLine = taskLine;
    }

    public Integer getNodeLevel() {
        return nodeLevel;
    }

    public void setNodeLevel(Integer nodeLevel) {
        this.nodeLevel = nodeLevel;
    }

    public String getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(String employeeId) {
        this.employeeId = employeeId;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public BigDecimal getPlanNum() {
        return planNum;
    }

    public void setPlanNum(BigDecimal planNum) {
        this.planNum = planNum;
    }

    public Integer getUnit() {
        return unit;
    }

    public void setUnit(Integer unit) {
        this.unit = unit;
    }

    public String getResourceName() {
        return resourceName;
    }

    public void setResourceName(String resourceName) {
        this.resourceName = resourceName;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public Integer getTypeUnit() {
        return typeUnit;
    }

    public void setTypeUnit(Integer typeUnit) {
        this.typeUnit = typeUnit;
    }

    public BigDecimal getNeedNum() {
        return needNum;
    }

    public void setNeedNum(BigDecimal needNum) {
        this.needNum = needNum;
    }

    public List<TotalPlanDetailChangeEntity> getChildren() {
        return children;
    }

    public void setChildren(List<TotalPlanDetailChangeEntity> children) {
        this.children = children;
    }

    /**
     * entity to vo
     */
    public static TotalPlanDetailChangeVO convertEntityToVo(TotalPlanDetailChangeEntity entity) {
        TotalPlanDetailChangeEntity copy = BeanMapper.map(entity, TotalPlanDetailChangeEntity.class);
        Long id = copy.getId();
        copy.setId(1L);
        String predecessorLink = copy.getPredecessorLink();
        copy.setPredecessorLink(null);
        String assignments = copy.getAssignments();
        copy.setAssignments(null);
        TotalPlanDetailChangeVO vo = BeanMapper.map(copy, TotalPlanDetailChangeVO.class);
        vo.setUid(id.toString());
        vo.setProjectUID(copy.getProjectId());
        vo.setParentTaskUID(copy.getParentId() + "");
        if (StringUtils.isNotBlank(assignments)) {
            vo.setAssignments(JSON.parseArray(assignments));
        }
        vo.setNote(copy.getNotes());
        vo.setId(copy.getTid());
        if(StringUtils.isNotBlank(predecessorLink)) {
            vo.setPredecessorLink(JSON.parseArray(predecessorLink));
        }
        return vo;
    }

    /**
     * vo to entity
     */
    public static TotalPlanDetailChangeEntity convertVoToEntity(TotalPlanDetailChangeVO vo) {
        TotalPlanDetailChangeEntity entity = BeanMapper.map(vo, TotalPlanDetailChangeEntity.class);
        if(StringUtils.isNotBlank(vo.getUid())) {
            entity.setId(Long.parseLong(vo.getUid()));
        }
        entity.setProjectId(vo.getProjectUID());
        if(StringUtils.isNotBlank(vo.getParentTaskUID())) {
            entity.setParentId(Long.parseLong(vo.getParentTaskUID()));
        }
        if(vo.getAssignments() != null && vo.getAssignments().size() > 0) {
            entity.setAssignments(JSON.toJSONString(vo.getAssignments()));
        }
        entity.setNotes(vo.getNote());
        entity.setTid(vo.getId());
        if(vo.getPredecessorLink() != null && vo.getPredecessorLink().size() > 0) {
            entity.setPredecessorLink(JSON.toJSONString(vo.getPredecessorLink()));
        }
        entity.setLastStart(DateUtil.setHours(vo.getLastStart(), 8));
        entity.setLastFinish(DateUtil.setHours(vo.getLastFinish(), 17));
        return entity;
    }
}
